<?php
/*
  index.php
  2004/12/2
ǽ2005/9/24

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('TEXT_MAIN', 'ŹϡosCommerceѤŽŹ󥿡ͥåΥȤΥץǤɤͳˤ');
define('TABLE_HEADING_NEW_PRODUCTS', '%s ο徦');
define('TABLE_HEADING_UPCOMING_PRODUCTS', 'ͽξ');
define('TABLE_HEADING_DATE_EXPECTED', 'ͽ');
define('TABLE_HEADING_RECOMMENDATION', 'Ź');

if ( ($category_depth == 'products') || ($HTTP_GET_VARS['manufacturers_id']) ) {
  define('HEADING_TITLE', '谷');
  define('TABLE_HEADING_IMAGE', '');
} elseif ($category_depth == 'top') {
  define('HEADING_TITLE', 'ä㤤ޤ');
} elseif ($category_depth == 'nested') {
  define('HEADING_TITLE', 'ƥ꡼');
}

define('HEADING_TITLE_CATEGORY', 'ƥ꡼');
define('TABLE_HEADING_MODEL', 'No.');
define('TABLE_HEADING_PRODUCTS', '̾');
define('TABLE_HEADING_SUBTITLE', '');
define('TABLE_HEADING_SERIES_TITLE', '꡼');
define('TABLE_HEADING_AUTHOR', '̾');
define('TABLE_HEADING_PUBLISHED', 'ǯ');
define('TABLE_HEADING_VOLUME', '');
define('TABLE_HEADING_ISBN', 'ISBN');
define('TABLE_HEADING_PUBLISHERS', 'Ǹ');
define('TABLE_HEADING_QUANTITY', '');
define('TABLE_HEADING_PRICE', '');
define('TABLE_HEADING_WEIGHT', '');
define('TABLE_HEADING_BUY_NOW', 'ʪ');
define('TABLE_HEADING_DESCRIPTION', '');

define('TEXT_NO_PRODUCTS', 'Υƥ꡼ξʤϤޤ...');
define('TEXT_NO_PRODUCTS2', '' . KN_CFG_USE_MANUFACTURERS . 'ξʤϤޤ...');
define('TEXT_NUMBER_OF_PRODUCTS', '߸˿: ');
define('TEXT_SHOW', '<strong>ʹ:</strong> ');
define('TEXT_BUY', ' ');
define('TEXT_NOW', ' ');	
define('TEXT_ALL', '');
?>
